==> haskell-rio-0.1.17.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio
version:              0.1.17.0
visibility:           public
id:                   rio-0.1.17.0-JmdYGojsep46wETr8HYGSs
key:                  rio-0.1.17.0-JmdYGojsep46wETr8HYGSs
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>

category:             Control
abi:                  1693cfadb87e7388e71a871ae789f404
exposed:              True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.Lens RIO.List RIO.List.Partial RIO.Map
    RIO.Map.Partial RIO.Map.Unchecked RIO.NonEmpty RIO.NonEmpty.Partial
    RIO.Partial RIO.Prelude RIO.Prelude.Simple RIO.Prelude.Types
    RIO.Process RIO.Seq RIO.Set RIO.Set.Partial RIO.Set.Unchecked
    RIO.State RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer

hidden-modules:
    RIO.Prelude.Display RIO.Prelude.Exit RIO.Prelude.Extra
    RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
    RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
    RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef

import-dirs:          /usr/lib/ghc-8.10.1/site-local/rio-0.1.17.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/rio-0.1.17.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/rio-0.1.17.0
hs-libraries:         HSrio-0.1.17.0-JmdYGojsep46wETr8HYGSs
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 exceptions-0.10.4
    filepath-1.4.2.1 hashable-1.3.0.0-AB9JnYTvt0wF1yqQjaMyNP
    microlens-0.4.11.2-DI50OTT3llTDsW32epWmE8
    microlens-mtl-0.2.0.1-30gu8BHYazP9sT79KAgW65 mtl-2.2.2
    primitive-0.7.1.0-DCpGwdehCUH1ptlZzcnzmj process-1.6.8.2
    text-1.2.3.2 time-1.9.3
    typed-process-0.2.6.0-LMQfHvJGCtIHrqnnkEcrmp unix-2.7.2.2
    unliftio-0.2.13-d4x9EU5AkKJ1aLdXHGCEf
    unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
    unordered-containers-0.2.11.0-9heg0ZMZ4fiE5I8jXNtXdI
    vector-0.12.1.2-CYdo0xBKGbnK8ZGEF4yFOM

haddock-interfaces:   /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html:         /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-0.1.18.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio
version:              0.1.18.0
visibility:           public
id:                   rio-0.1.18.0-4d63LrIUlxjHh5QagQcp9I
key:                  rio-0.1.18.0-4d63LrIUlxjHh5QagQcp9I
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>

category:             Control
abi:                  6f833f93d8dfab9f933574dc8ae463d4
exposed:              True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.Lens RIO.List RIO.List.Partial RIO.Map
    RIO.Map.Partial RIO.Map.Unchecked RIO.NonEmpty RIO.NonEmpty.Partial
    RIO.Partial RIO.Prelude RIO.Prelude.Simple RIO.Prelude.Types
    RIO.Process RIO.Seq RIO.Set RIO.Set.Partial RIO.Set.Unchecked
    RIO.State RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer

hidden-modules:
    RIO.Prelude.Display RIO.Prelude.Exit RIO.Prelude.Extra
    RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
    RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
    RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef

import-dirs:          /usr/lib/ghc-8.10.1/site-local/rio-0.1.18.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/rio-0.1.18.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/rio-0.1.18.0
hs-libraries:         HSrio-0.1.18.0-4d63LrIUlxjHh5QagQcp9I
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 exceptions-0.10.4
    filepath-1.4.2.1 hashable-1.3.0.0-DiGbvYLsPmxJgdfVCor8qD
    microlens-0.4.11.2-DI50OTT3llTDsW32epWmE8
    microlens-mtl-0.2.0.1-30gu8BHYazP9sT79KAgW65 mtl-2.2.2
    primitive-0.7.1.0-Fy9GtLXiUTxJSxYCQpQePZ process-1.6.8.2
    text-1.2.3.2 time-1.9.3 typed-process-0.2.6.0-LCsR9SYv8XqgRqGW0jkue
    unix-2.7.2.2 unliftio-0.2.13-1MFPbvwaWqI2gFtE11C0VP
    unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
    unordered-containers-0.2.12.0-7yiTvjz2UcTGgWhTtgXiX9
    vector-0.12.1.2-8A0MDgLPPVcWTXsA8tpNg

haddock-interfaces:   /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html:         /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
